PyRCS
=====

|PyPI| |Python| |License| |Code size| |Downloads|

.. |PyPI| image:: https://img.shields.io/pypi/v/pyrcs?color=important&label=PyPI
   :target: https://pypi.org/project/pyrcs/
.. |Python| image:: https://img.shields.io/pypi/pyversions/pyrcs?color=informational&label=Python
   :target: https://www.python.org/downloads/
.. |License| image:: https://img.shields.io/pypi/l/pyrcs?color=green&label=License
   :target: https://github.com/mikeqfu/pyrcs/blob/master/LICENSE
.. |Code size| image:: https://img.shields.io/github/languages/code-size/mikeqfu/pyrcs?color=yellowgreen&label=Code%20size
   :target: https://github.com/mikeqfu/pyrcs/tree/master/pyrcs
.. |Downloads| image:: https://img.shields.io/pypi/dm/pyrcs?color=yellow&label=Downloads
   :target: https://pypistats.org/packages/pyrcs

**Author**: Qian Fu |Twitter|

.. |Twitter| image:: https://img.shields.io/twitter/url/https/twitter.com/Qian_Fu?label=Follow&style=social
   :target: https://twitter.com/Qian_Fu

PyRCS is a web-scraping tool for collecting `acronyms and codes <http://www.railwaycodes.org.uk/>`_ being used in Britain's railway.

Resources
---------

- `Documentation <https://pyrcs.readthedocs.io/>`_
- `Issue Tracker <https://github.com/mikeqfu/pyrcs/issues>`_

License
-------

PyRCS is licensed under `GNU General Public License v3.0 (GPLv3) <https://github.com/mikeqfu/pyrcs/blob/master/LICENSE>`_.

Acknowledgements
----------------

Acknowledgements are given to those who contribute to the data resources: http://www.railwaycodes.org.uk/misc/acknowledgements.shtm
